@@ -71,6 +71,11 @@ if( !$this->CheckPermission(ORDERS_PERM_MANAGEORDERS) )
     $order->hide_ccinfo();
   }
 
+if( $this->CheckPermission(ORDERS_PERM_MANAGEORDERS) )
+  {
+  }
+
+
 //
 // Handle submit
 //
@@ -132,6 +137,8 @@ if( $this->CheckPermission(ORDERS_PERM_MANAGEORDERS) )
     $statuses[$this->Lang(ORDERSTATUS_SUBSCRIBED)] = ORDERSTATUS_SUBSCRIBED;
     $statuses = array_flip($statuses);
     $smarty->assign('order_statuses',$statuses);
+//     $smarty->assign('input_status',
+// 		    $this->CreateInputDropdown($id,'input_status',$statuses,-1,$order->get_status()));
     $smarty->assign('submit',
 		    $this->CreateInputSubmit($id,'submit',$this->Lang('submit')));
     $smarty->assign('cancel',
@@ -182,22 +189,6 @@ $smarty->assign('order',$order);
 $smarty->assign('print_img',$this->DisplayImage('printer.png',$this->Lang('print_invoice')));
 $smarty->assign('invoice_img',$this->DisplayImage('invoice_lg.gif',$this->Lang('create_invoice')));
 $smarty->assign('can_manage_orders',$this->CheckPermission(ORDERS_PERM_MANAGEORDERS));
-{
-  $have_module = FALSE;
-  $ccprocessing_module = $this->GetPreference('ccprocessing_module');
-  if( $ccprocessing_module )
-    {
-      $obj = $this->GetModuleInstance($ccprocessing_module);
-      if( is_object($obj) )
-	{
-	  if( $obj->SupportsRefunds() )
-	    {
-	      $have_module = TRUE;
-	    }
-	}
-    }
-  $smarty->assign('can_refund',$this->CheckPermission(ORDERS_PERM_MANAGEORDERS) && $have_module);
-}
 echo $this->ProcessTemplate('admin_manageorder.tpl');
 
 #
