@@ -35,8 +35,21 @@
 if( !isset($gCms) ) exit;
 
 require_once(dirname(__FILE__).'/lib/class.orders_ops.php');
+$gateway_module = cg_ecomm::get_payment_module();
+if( !is_object($gateway_module) )
+  {
+    // should never get here... display some weird message.
+    echo $this->DisplayErrorMessage($this->Lang('error_insufficientparams'));
+    return;
+  }
+if( !$gateway_module->RequiresCreditCardInfo() )
+  {
+    // should never get here... display some weird message.
+    echo $this->DisplayErrorMessage($this->Lang('error_insufficientparams'));
+    return;
+  }
 // redirect to https if required, include weird check for IIS. SjG
-if (orders_helper::creditcard_requires_ssl() &&
+if ($gateway_module->RequiresSSL() &&
    (! isset($_SERVER['HTTPS']) || empty($_SERVER['HTTPS']) || $_SERVER['HTTPS'] == 'off'))
   {
     cge_redirect::redirect_https();
@@ -111,7 +124,7 @@ if( isset($params['submit']) )
       {
 	$smarty->assign('error',$this->Lang('error_insufficientparams'));
       }
-    else if( strlen($ccnumber) != 16 )
+    else if( strlen($ccnumber) > 16 || strlen($ccnumber) < 15 )
       {
 	$smarty->assign('error',$this->Lang('error_invalidfield',$this->Lang('creditcard')));
       }
