@@ -35,13 +35,11 @@
 if( !isset($gCms) ) exit;
 
 $feu_group = $this->GetPreference('require_membership','-1');
-if( !$this->GetPreference('allow_anon_checkout') && $feu_group == -1 )
-  {
-    echo $this->ShowErrors($this->Lang('error_norequiredgroup'));
-  }
+if( !$this->GetPreference('allow_anon_checkout') && $feu_group == -1 ) {
+  echo $this->ShowErrors($this->Lang('error_norequiredgroup'));
+}
 
-$smarty->assign('formstart',
-		$this->CGCreateFormStart($id,'admin_save_address'));
+$smarty->assign('formstart',$this->CGCreateFormStart($id,'admin_save_address'));
 $smarty->assign('formend',$this->CreateFormEnd());
 
 $address_options = array();
@@ -54,56 +52,48 @@ $smarty->assign('address_retrieval',$this->GetPreference('address_retrieval','re
 
 $smarty->assign('require_state',$this->GetPreference('require_state',1));
 $smarty->assign('require_postalcode',$this->GetPreference('require_postalcode',1));
-$smarty->assign('input_dflt_state',
-                $this->CreateInputText($id,'dflt_state',$this->GetPreference('dflt_state',''),2,2));
-$smarty->assign('input_dflt_country',
-                $this->CreateInputText($id,'dflt_country',$this->GetPreference('dflt_country',''),2,2));
+$smarty->assign('input_dflt_state', $this->CreateInputText($id,'dflt_state',$this->GetPreference('dflt_state',''),2,2));
+$smarty->assign('input_dflt_country',$this->CreateInputText($id,'dflt_country',$this->GetPreference('dflt_country',''),2,2));
 
 
 $serialized = $this->GetPreference('address_map','');
 $address_map = new orders_address();
 $tmp = $address_map->to_array();
-foreach( $tmp as $key => $value )
-{
+foreach( $tmp as $key => $value ) {
   $tmp[$key] = -1;
 }
 $address_map->from_array($tmp,'');
-if( $serialized )
-  {
-    $tmp = unserialize($serialized);
-    $address_map->from_array($tmp,'');
-  }
+if( $serialized ) {
+  $tmp = unserialize($serialized);
+  $address_map->from_array($tmp,'');
+}
 $smarty->assign('map',$address_map);
 $smarty->assign('valid_countries',$this->GetPreference('valid_countries',''));
 $smarty->assign('valid_states',$this->GetPreference('valid_states',''));
 
+if( $feu_group != '-1' ) {
+  // get the list of properties for this group
+  $feu = $this->GetModuleInstance('FrontEndUsers');
+  if( $feu ) {
+    // get all the property definitions
+    $defns = $feu->GetPropertyDefns();
 
-if( $feu_group != '-1' )
-  {
-    // get the list of properties for this group
-    $feu =& $this->GetModuleInstance('FrontEndUsers');
-    if( $feu )
-      {
-	// get all the property definitions
-	$defns = $feu->GetPropertyDefns();
-	
-	// get all the properties for this group.
-	$relns = $feu->GetGroupPropertyRelations($feu_group);
-	
-	// build an array of all of the property values
-	$props = array();
-	$props[-1] = $this->Lang('none');
-	$props['__USERNAME__'] = $this->Lang('prompt_username');
-	$props['__EMAIL__'] = $this->Lang('prompt_email');
-	for( $i = 0; $i < count($relns); $i++ )
-	  {
-	    $name = $relns[$i]['name'];
-	    $props[$name] = $defns[$name]['prompt']." ($name)";
-	  }
+    // get all the properties for this group.
+    $relns = $feu->GetGroupPropertyRelations($feu_group);
 
-	$smarty->assign('properties',$props);
-      }
+    // build an array of all of the property values
+    $props = array();
+    $props[-1] = $this->Lang('none');
+    $props['__USERNAME__'] = $this->Lang('prompt_username');
+    $props['__EMAIL__'] = $this->Lang('prompt_email');
+    for( $i = 0; $i < count($relns); $i++ ) {
+      $name = $relns[$i]['name'];
+      $props[$name] = $defns[$name]['prompt']." ($name)";
+    }
+
+    $smarty->assign('properties',$props);
   }
+}
 
 echo $this->ProcessTemplate('address_tab.tpl');
 // EOF
