@@ -142,49 +142,6 @@ $lang['gateway_complete_templates'] = 'Gabarits de fin de transaction de paiemen
 $lang['gateway_failure_message'] = 'L&#039;op&eacute;ration de paiement n&#039;a pas pu se terminer normalement. Il se peut que l&#039;op&eacute;ration aie &eacute;t&eacute; annul&eacute;e, ou qu&#039;une erreur se soit produite. Merci de v&eacute;rifier les informations de paiement que vous avez indiqu&eacute;, et de r&eacute;-essayer. Pour des raisons de s&eacute;curit&eacute;, votre panier a &eacute;t&eacute; compl&egrave;tement vid&eacute;. Merci de votre patience.';
 $lang['general_settings'] = 'Pr&eacute;f&eacute;rences G&eacute;n&eacute;rales';
 $lang['get_address_from_feu'] = 'Utiliser le profil de l&#039;utilisateur';
-$lang['help'] = '<h3>Que fait ce module ?</h3>
-  <p>Ce module permet de tranformer un panier d&#039;achat en commande, et de suivre cette commande. Il demande au client les informations de facturation et de livraison, et permet:<ul>
-<li>soit d&#039;effectuer un paiement via une passerelle de paiement externe,</li>
-<li>soit d&#039;envoyer une facture par e-mail.</li>
-</ul>
-</p>
-  <p>Si besoin est, le module peut demander au client les informations n&eacute;cessaires &agrave; un paiement par carte bancaire, et les stocker en base de donn&eacute;es afin qu&#039;elles puissent &ecirc;tre trait&eacute;es manuellement.</p>
-  <p>Le module assure le suivi de chaque commande, et permet d&#039;utiliser des informations de type num&eacute;ros de suivi et codes de confirmation. Il permet aussi d&#039;envoyer par e-mail aux clients des informations relatives aux commandes en cours.</p>
-
-<h3>Comment utiliser ce module ?</h3>
-
-<p>Ce module fonctionne en collaboration avec le modume Panier. Cr&eacute;ez une page, et appelez-l&agrave; &quot;Paiement&quot;. Son contenu doit &ecirc;tre &quot;{Orders}&quot;.  Cette page permet de d&eacute;marrer le processus de paiement.</p>
-<h3><span style=&quot;color: red;&quot;>Avertissement sur les donn&eacute;es de carte de cr&eacute;dit</span></h3>
-<p>Il est fortement d&eacute;conseill&eacute; d&#039;utiliser la saisie directe d&#039;informations de carte de cr&eacute;dit, &agrave; moins que vous mettiez en place une communication s&eacute;curis&eacute;e vers un h&eacute;bergement s&eacute;curis&eacute; et r&eacute;serv&eacute; au traitement d&#039;informations confidentielles et sensibles. Bien qu&#039;il utilise un m&eacute;canisme de cryptage simple, ce module ne peut garantir &agrave; lui seul la s&eacute;curit&eacute; des informations stock&eacute;es en base de donn&eacute;es, qui restent vuln&eacute;rables aux attaques.</p>
-
-<h3>Assistance</h3>
-<p>Ce module est fourni sans aucune assistance commerciale. Cependant, vous pouvez tout de m&ecirc;me obtenir de l&#039;aide:</p>
-<ul>
-<li>Les <a href="http://forum.cmsmadesimple.org">Forums CMS Made Simple</a> sont une pr&eacute;ciseuse source d&#039;informations.</li>
-<li>Vous pouvez contacter calguy1000, l&#039;auteur du module sur <a href="irc://irc.freenode.net/#cms">le channel IRC CMS</a>.</li>
-<li>En dernier ressort, vous pouvez tenter de joindre l&#039;auteur par e-mail.</li>  
-</ul>
-<br/>
-<h3>Copyright et License</h3>
-<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. Tous droits r&eacute;serv&eacute;s.</p>
-<p>This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.</p>
-<p>However, as a special exception to the GPL, this software is distributed
-as an addon module to CMS Made Simple.  You may not use this software
-in any Non GPL version of CMS Made simple, or in any version of CMS
-Made simple that does not indicate clearly and obviously in its admin 
-section that the site was built with CMS Made simple.</p>
-<p>This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
-$lang['help_param_invoice_prefix'] = 'Ce param&egrave;tre vous permet d&#039;entrer jusqu&#039;&agrave; 4 caract&egrave;res &agrave; utiliser en tant que pr&eacute;fixe pour la g&eacute;n&eacute;ration de num&eacute;ros de factures. Si rien n&#039;est sp&eacute;cifi&eacute;, le pr&eacute;fixe utilis&eacute; sera celui des pr&eacute;f&eacute;rences du module.';
 $lang['help_param_nocaptcha'] = 'Si ce param&egrave;tre est indiqu&eacute;, captcha sera d&eacute;sactiv&eacute;';
 $lang['help_param_template'] = 'Sp&eacute;cifie un gabarit qui n&#039;est pas le gabarit par d&eacute;faut pour l&#039;utilisation de l&#039;action par defaut';
 $lang['hold'] = 'Suspendre';
@@ -433,4 +390,4 @@ $lang['utmz'] = '156861353.1301379144.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd
 $lang['utma'] = '156861353.1385159307.1301379144.1301572522.1301577918.3';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
-?>
\ No newline at end of file
+?>
