@@ -142,43 +142,6 @@ $lang['gateway_complete_templates'] = 'Gateway volledigheidssjabloon';
 $lang['gateway_failure_message'] = 'Uw transactie is niet afgerond.  Of de actie is be&euml;indigd of er is een storing opgetreden.  Controleert u uw betalingsgegevens en probeer het opnieuw. Uw winkelwagen is geleegd voor uw veiligheid. Bedankt voor uw tijd.';
 $lang['general_settings'] = 'Algemene instellingen';
 $lang['get_address_from_feu'] = 'Gebruik klantprofiel';
-$lang['help'] = '<h3>What does it do?</h3>
-  <p>This module is a module for turning a filled cart into a completed Order.  This module handles collecting billing information and shipping information from the user and then either using an external payment gateway to handle payment information, or performing direct email based invoicing.</p>
-  <p>This module can also optionally collect credit card information and store it in the database for later offline processing.</p>
-  <p>The orders module keeps track of all orders, and allows specifying items like tracking numbers and confirmation numbers, and also allows sending emails to the client pertaining to a particular order.</p>
-<h3>How Do I use It?</h3>
-<p>This module works in conjunction with the Cart module.  Create a page, call it &quot;Checkout&quot; and set it&#039;s content should be &quot;{Orders}&quot;.  This page will start the Checkout process.</p>
-<h3><span style=&quot;color: red;&quot;>Warning - Credit Card Information</span></h3>
-<p>It is not recommended that you use the credit card number gathering mechanism unless using a secure communications mechanism and only on secured, dedicated hosts.  There is no guarantee that the database numbers (though a simple encryption mechanism is used) are not vulnerable to theft.</p>
-
-<h3>Support</h3>
-<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
-<ul>
-<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
-<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
-<li>Lastly, you may have some success emailing the author directly.</li>  
-</ul>
-<br/>
-<h3>Copyright and License</h3>
-<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
-<p>This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.</p>
-<p>However, as a special exception to the GPL, this software is distributed
-as an addon module to CMS Made Simple.  You may not use this software
-in any Non GPL version of CMS Made simple, or in any version of CMS
-Made simple that does not indicate clearly and obviously in its admin 
-section that the site was built with CMS Made simple.</p>
-<p>This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
-$lang['help_param_invoice_prefix'] = 'Met deze parameter kunt u tot 4 tekens een prefix opgeven die wordt gebruikt voor het genereren van een ordernummer. Als dit niet is opgegeven, dan zal de prefix opgegeven in de module voorkeuren gebruikt worden.';
 $lang['help_param_nocaptcha'] = 'Inschakelen van deze parameter, schakelt Captcha uit';
 $lang['help_param_template'] = 'Specificeer een niet standaard sjabloon voor deze standaard actie';
 $lang['hold'] = 'Houd vast';
@@ -428,4 +391,4 @@ $lang['utmz'] = '156861353.1305060417.143.89.utmcsr=forum.cmsmadesimple.org|utmc
 $lang['qca'] = 'P0-161031897-1287479092171';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-?>
\ No newline at end of file
+?>
