@@ -57,10 +57,7 @@ class orders_order
   public function set_id($val,$set_invoice = false)
   {
     $this->_id = $val;
-    if( $set_invoice )
-      {
-	$this->set_invoice(orders_helper::make_invoice_number($this->get_id()));
-      }
+    if( $set_invoice )$this->set_invoice(orders_helper::make_invoice_number($this->get_id()));
   }
 
 
@@ -150,15 +147,9 @@ class orders_order
 
   public function add_shipping(orders_shipping &$shipping,$reset_id = true)
   {
-    if( $reset_id )
-      {
-	$shipping->set_id(null);
-      }
+    if( $reset_id ) $shipping->set_id(null);
     $shipping->set_order_id($this->get_id());
-    if( !is_array($this->_shipping_recs) )
-      {
-	$this->_shipping_recs = array();
-      }
+    if( !is_array($this->_shipping_recs) ) $this->_shipping_recs = array();
     $this->_shipping_recs[] = $shipping;
   }
 
@@ -166,23 +157,16 @@ class orders_order
   public function del_shipping($idx)
   {
     $new_data = array();
-    for( $i = 0; $i < count($this->_shipping_recs); $i++ )
-      {
-	if( $i != $idx )
-	  {
-	    $new_data[] = $this->_shipping_recs[$i];
-	  }
-      }
+    for( $i = 0; $i < count($this->_shipping_recs); $i++ ) {
+      if( $i != $idx ) $new_data[] = $this->_shipping_recs[$i];
+    }
     $this->_shipping_recs = $new_data;
   }
 
 
   public function &get_shipping($idx)
   {
-    if( $idx >= 0 && $idx < count($this->_shipping_recs) )
-      {
-	return $this->_shipping_recs[$idx];
-      }
+    if( $idx >= 0 && $idx < count($this->_shipping_recs) ) return $this->_shipping_recs[$idx];
   }
 
 
@@ -201,26 +185,19 @@ class orders_order
   public function count_real_items()
   {
     $itemcount = 0;
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	$itemcount += $shipping->count_real_items();
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      $itemcount += $shipping->count_real_items();
+    }
     return $itemcount;
   }
 
 
   public function add_payment(orders_payment &$payment,$reset_id = true)
   {
-    if( $reset_id )
-      {
-	$payment->set_id(null);
-      }
+    if( $reset_id ) $payment->set_id(null);
     $payment->set_order_id($this->get_id());
-    if( !is_array($this->_payment_recs) )
-      {
-	$this->_payment_recs = array();
-      }
+    if( !is_array($this->_payment_recs) ) $this->_payment_recs = array();
     $this->_payment_recs[] = $payment;
   }
 
@@ -239,23 +216,16 @@ class orders_order
 
   public function &get_payment($idx)
   {
-    if( $idx >= 0 && $idx < count($this->_payment_recs) )
-      {
-	return $this->_payment_recs[$idx];
-      }
+    if( $idx >= 0 && $idx < count($this->_payment_recs) ) return $this->_payment_recs[$idx];
   }
 
 
   public function &get_payment_by_id($pmt_id)
   {
     $res = null;
-    for( $i = 0; $i < count($this->_payment_recs); $i++ )
-      {
-	if( $this->_payment_recs[$i]->get_id() == $pmt_id )
-	  {
-	    $res =& $this->_payment_recs[$i];
-	  }
-      }
+    for( $i = 0; $i < count($this->_payment_recs); $i++ ) {
+      if( $this->_payment_recs[$i]->get_id() == $pmt_id ) $res =& $this->_payment_recs[$i];
+    }
     return $res;
   }
 
@@ -263,28 +233,18 @@ class orders_order
   public function &get_payment_by_txn_id($txn_id)
   {
     $res = null;
-    for( $i = 0; $i < count($this->_payment_recs); $i++ )
-      {
-	if( $this->_payment_recs[$i]->get_txn_id() == $txn_id )
-	  {
-	    $res =& $this->_payment_recs[$i];
-	  }
-      }
+    for( $i = 0; $i < count($this->_payment_recs); $i++ ) {
+      if( $this->_payment_recs[$i]->get_txn_id() == $txn_id ) $res =& $this->_payment_recs[$i];
+    }
     return $res;
   }
 
 
   public function add_note(orders_message &$message,$reset_id = true)
   {
-    if( $reset_id )
-      {
-	$message->set_id(null);
-      }
+    if( $reset_id ) $message->set_id(null);
     $message->set_order_id($this->get_id());
-    if( !is_array($this->_note_recs) )
-      {
-	$this->_note_recs = array();
-      }
+    if( !is_array($this->_note_recs) ) $this->_note_recs = array();
     $this->_note_recs[] = $message;
   }
 
@@ -303,33 +263,25 @@ class orders_order
 
   public function &get_note($idx)
   {
-    if( $idx >= 0 && $idx < count($this->_note_recs) )
-      {
-	return $this->_note_recs[$idx];
-      }
+    if( $idx >= 0 && $idx < count($this->_note_recs) ) return $this->_note_recs[$idx];
   }
 
 
   public function get_note_by_id($note_id)
   {
-    for( $i = 0; $i < count($this->_note_recs); $i++ )
-      {
-	if( $this->_note_recs[$i]->get_id() == $note_id )
-	  {
-	    return $this->_note_recs[$i];
-	  }
-      }
+    for( $i = 0; $i < count($this->_note_recs); $i++ ) {
+      if( $this->_note_recs[$i]->get_id() == $note_id ) return $this->_note_recs[$i];
+    }
   }
 
 
   public function get_weight()
   {
     $weight = 0;
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	$weight += $shipping->get_weight();
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      $weight += $shipping->get_weight();
+    }
     return $weight;
   }
 
@@ -337,23 +289,21 @@ class orders_order
   public function get_subtotal()
   {
     $subtotal = 0;
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	$subtotal += $shipping->get_subtotal();
-      }
-    return $subtotal;
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      $subtotal += $shipping->get_subtotal();
+    }
+    return max(0.0,$subtotal);
   }
 
 
   public function get_shipping_cost()
   {
     $shipping_cost = 0;
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	$shipping_cost += $shipping->get_shipping_cost();
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      $shipping_cost += $shipping->get_shipping_cost();
+    }
     return $shipping_cost;
   }
 
@@ -361,11 +311,10 @@ class orders_order
   public function get_tax_cost()
   {
     $tax_cost = 0;
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	$tax_cost += $shipping->get_tax_cost();
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      $tax_cost += $shipping->get_tax_cost();
+    }
     return $tax_cost;
   }
 
@@ -373,32 +322,36 @@ class orders_order
   public function get_discount()
   {
     $discount = 0;
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	$discount += $shipping->get_discount();
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      $discount += $shipping->get_discount();
+    }
+
+    // discount can never exceed the subtotal.
+    $subtotal = $this->get_subtotal() * -1;
+    $discount = max($subtotal,$discount);
     return $discount;
   }
 
 
   public function get_total()
   {
-    return $this->get_subtotal() + $this->get_shipping_cost() +
-      $this->get_tax_cost() + $this->get_discount();
+    // this should be done in a post processing step.
+    $val = max(0,$this->get_subtotal()) + $this->get_shipping_cost() +
+      max(0,$this->get_tax_cost()) + $this->get_discount();
+    $val = max(0,$val);
+    return $val;
   }
 
 
   public function get_amount_paid()
   {
     $sum = 0;
-    for( $i = 0; $i < $this->count_payments(); $i++ )
-      {
-	$payment =& $this->_payment_recs[$i];
-	if( $payment->get_status() != orders_payment::STATUS_APPROVED )
-	  continue;
-	$sum += $payment->get_amount();
-      }
+    for( $i = 0; $i < $this->count_payments(); $i++ ) {
+      $payment =& $this->_payment_recs[$i];
+      if( $payment->get_status() != orders_payment::STATUS_APPROVED ) continue;
+      $sum += $payment->get_amount();
+    }
     return $sum;
   }
 
@@ -411,76 +364,67 @@ class orders_order
 
   public function save($del_children = false)
   {
-    if( $this->get_id() > 0 )
-      {
-	return orders_ops::update($this,$del_children);
-      }
+    if( $this->get_id() > 0 ) return orders_ops::update($this,$del_children);
     return orders_ops::insert($this);
   }
 
 
   public function is_all_shipped()
   {
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	if( !$shipping->is_all_shipped() ) return FALSE;
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      if( !$shipping->is_all_shipped() ) return FALSE;
+    }
     return TRUE;
   }
 
 
   public function is_partially_shipped()
   {
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	if( !$shipping->is_partially_shipped() ) return FALSE;
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      if( !$shipping->is_partially_shipped() ) return FALSE;
+    }
     return TRUE;
   }
 
 
   public function has_services()
   {
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	if( $shipping->has_services() ) return TRUE;
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      if( $shipping->has_services() ) return TRUE;
+    }
     return FALSE;
   }
 
 
   public function is_service_only()
   {
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	if( !$shipping->is_service_only() ) return FALSE;
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      if( !$shipping->is_service_only() ) return FALSE;
+    }
     return TRUE;
   }
 
 
   public function has_subscriptions()
   {
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	if( $shipping->has_subscriptions() ) return TRUE;
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      if( $shipping->has_subscriptions() ) return TRUE;
+    }
     return FALSE;
   }
 
 
   public function is_subscription_only()
   {
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	if( !$shipping->is_subscription_only() ) return FALSE;
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      if( !$shipping->is_subscription_only() ) return FALSE;
+    }
     return TRUE;
   }
 
@@ -517,18 +461,16 @@ class orders_order
     $result = array_merge($tmp,$result);
 
     $result['shipping'] = array();
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping = $this->get_shipping($i);
-	$result['shipping'][] = $shipping->to_array();
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping = $this->get_shipping($i);
+      $result['shipping'][] = $shipping->to_array();
+    }
 
     $result['payments'] = array();
-    for( $i = 0; $i < $this->count_payments(); $i++ )
-      {
-	$payment = $this->get_payment($i);
-	$result['payments'][] = $payment->to_array();
-      }
+    for( $i = 0; $i < $this->count_payments(); $i++ ) {
+      $payment = $this->get_payment($i);
+      $result['payments'][] = $payment->to_array();
+    }
 
     // for backward compatibilty... remove me soon.
     $result['subtotal'] = $this->get_subtotal();
@@ -542,11 +484,10 @@ class orders_order
   public function reset_ids()
   {
     $this->set_id(null);
-    for( $i = 0; $i < $this->count_destinations(); $i++ )
-      {
-	$shipping =& $this->get_shipping($i);
-	$shipping->reset_ids();
-      }
+    for( $i = 0; $i < $this->count_destinations(); $i++ ) {
+      $shipping =& $this->get_shipping($i);
+      $shipping->reset_ids();
+    }
   }
 
 
