@@ -189,14 +189,13 @@ $sqlarray = $dict->CreateIndexSQL('orders_messages',cms_db_prefix().'module_orde
 				  'order_id');
 $dict->ExecuteSQLArray($sqlarray);
 
-# Templates
-$fn = cms_join_path(dirname(__FILE__),'templates','orig_paymentform_template.tpl');
+$fn = cms_join_path(dirname(__FILE__),'templates','orig_shippingform_template.tpl');
 if( file_exists( $fn ) )
   {
     $template = file_get_contents( $fn );
-    $this->SetPreference('systemdflt_paymentform_template',$template);
-    $this->SetTemplate('paymentform_Sample',$template);
-    $this->SetPreference('dflt_paymentform_template','Sample');
+    $this->SetPreference('systemdflt_shippingform_template',$template);
+    $this->SetTemplate('shippingform_Sample',$template);
+    $this->SetPreference('dflt_shippingform_template','Sample');
   }
 
 $fn = cms_join_path(dirname(__FILE__),'templates','orig_invoice_template.tpl');
